@@ -1,6 +1,6 @@
 package IO::Prompt;
 
-our $VERSION = '0.997003';
+our $VERSION = '0.997004';
 
 use strict;
 use Carp;
@@ -13,7 +13,8 @@ our @EXPORT_OK = qw( hand_print get_input );
 
 use IO::Handle;
 use Term::ReadKey;
-use POSIX qw( isprint );
+
+sub _isprint { $_[0] =~ qr/ ^ [[:print:]]+ $ /x }
 
 my $clearfirst;
 my %input;
@@ -323,7 +324,7 @@ my $baseline = ord 'A';
 
 sub _visualize {
     local ($_) = @_;
-    return isprint($_)         ? $_
+    return _isprint($_)        ? $_
          : $_ eq "\n"          ? $_
          : ord($_) == 0        ? ''
          : ord($_) < $baseline ? '^' . chr($baseline + ord($_) - 1)
@@ -644,7 +645,7 @@ Use the IO::Prompter module instead.
 
 =head1 VERSION
 
-This document describes IO::Prompt version 0.997003
+This document describes IO::Prompt version 0.997004
 
 =head1 SYNOPSIS
 
@@ -848,10 +849,6 @@ IO::Handle
 
 Term::ReadKey
 
-=item *
-
-POSIX
-
 =back
 
 
